import React from 'react';
import { scaleTime, extent, scaleLinear, max, line, timeFormat } from 'd3';
import { XAxis } from './XAxis';
import { YAxis } from './YAxis';

const xValue = d => d.year;
const yValue = d => d.expectancy;

const margin = { top: 40, right: 80, bottom: 80, left: 150 };

export const LineChart = ({ data, width, height }) => {
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  
//Define x-axis range
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);

  
//Define y-axis range
  const maxRange = parseFloat(max(data, yValue)) + .1;
  const yScale = scaleLinear()
    .domain([0, maxRange + 10])
    .range([innerHeight, 0]);


//Define line graph structure  
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)));

  const mostRecentDate = xScale.domain()[1];

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <XAxis xScale={xScale} innerHeight={innerHeight} />
        <YAxis yScale={yScale} innerWidth={innerWidth} />
        <path d={lineGenerator(data)} />
      </g>
    </svg>
  );
};
